@@ -291,6 +291,17 @@ def del_key( kn ) :
     #s_log.write_msg("GET KEY NULL")
     return False
 
+################################################################
+
+def generate_save( fp , cdict ) :
+    data = {
+        "sapiadapter" : cdict
+    }
+
+    s_util.json_save( fp , data )
+
+
+
 ################################################################
 
 def init_fromfile( config_path , config_key = "sapiadapter" ) :
