@@ -20,6 +20,7 @@ import time
 import platform
 import hashlib
 import sqlite3
+from pathlib import Path
 
 from . import s_log , s_config , s_util
 
@@ -29,6 +30,25 @@ def setup( ) :
     s_log.write( "setup" )
     filedir_create( )
 
+#####################################################################
+
+
+def db_stash( ) :
+    curr_fp = filepath_get( )
+    new_fp = curr_fp + "-STASH"
+    os.rename( curr_fp , new_fp )
+    data={
+        "curr_fp":curr_fp,
+        "new_fp":new_fp
+    }
+    return(s_util.json_encode(data))
+
+def db_unstash( data_json ) :
+    data=s_util.json_loads(data_json)
+    os.rename( data["new_fp"] , data["curr_fp"])
+
+
+
 #####################################################################
 
 def filedir_create( ) :
@@ -84,7 +104,7 @@ def sql_execute( sql , params_tuple = False ) :
 
     dbcon = sqlite3.connect( filepath_get( ) )
     cur = dbcon.cursor( )
-    if params_tuple==False:
+    if params_tuple == False:
         cur.execute( sql )
     else:
         cur.execute( sql , params_tuple )
@@ -305,7 +325,7 @@ def stacks_create( sv_data , sk = 0 ) :
 
     sv = s_util.json_encode( sv_data )
 
-    sql = "INSERT INTO stacks ( sid , sk,sv ) VALUES ( ? , ? , ? )"
+    sql = "INSERT INTO stacks ( sid , sk , sv ) VALUES ( ? , ? , ? )"
     data = ( None , sk,sv )
 
     sql_execute( sql , data )
@@ -644,6 +664,20 @@ def files_readallmeta( ) :
     rows = sql_execute_fetch( sql , fetch_all = True )
     return( rows )
 
+def files_restore( ) :
+    db_files=files_readallmeta( )
+    for db_file in db_files :
+
+        fp = db_file[ "fp" ]
+
+        dp = s_util.path_dirname( fp )
+        #print(dp)
+        dp_path = Path( dp )
+        dp_path.mkdir( parents = True , exist_ok = True )
+
+        with open( fp , "wb" ) as f :
+            f.write( files_getcontent( fp ) )
+
 
 ####################################################################
 
